@@ -2,25 +2,24 @@ import logging
 import os.path
 import sys
 
+import inforion.ionapi.model.inforlogin as inforlogin
 import pandas as pd
 import pyodbc
 import validators
-
-import inforion.ionapi.model.inforlogin as inforlogin
 from inforion.helper.urlsplit import spliturl
 from inforion.helper.util import get_db_credentials
 from inforion.helper.validations import validate_db_credentials
 from inforion.ionapi.controller import *
 from inforion.ionapi.model import *
+from inforion.logger.logger import get_logger
 from inforion.merging.merging import merge_files
 from inforion.transformation.transform import parallelize_tranformation
 
-from inforion.logger.logger import get_logger
-
 logger = get_logger("inforion-init", True)
 
 # Codee Junaid
 
+
 def main_load(
     url=None,
     ionfile=None,
@@ -117,12 +116,14 @@ def main_transformation(
             mappingfile, mainsheet, stagingdata, outputfile
         )
     except Exception as ex:
-        if ex.message:
+        logger.exception(ex)
+        if hasattr(ex, "message"):
             return "There is an error while transforming the records. " + ex.message
         else:
-            return "There is an unknown error while transforming the records."
+            return "There is an unknown error while transforming the records. "
         sys.exit(1)
 
+
 def main_transformation_from_db(
     mappingfile=None, mainsheet=None, db_config=None, table_name=None, outputfile=None
 ):
